/****************************************************************************
** Meta object code from reading C++ file 'qsensor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtsensors/src/sensors/qsensor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qsensor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7QSensorE_t {};
} // unnamed namespace

template <> constexpr inline auto QSensor::qt_create_metaobjectdata<qt_meta_tag_ZN7QSensorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QSensor",
        "busyChanged",
        "",
        "activeChanged",
        "readingChanged",
        "sensorError",
        "error",
        "availableSensorsChanged",
        "alwaysOnChanged",
        "dataRateChanged",
        "skipDuplicatesChanged",
        "skipDuplicates",
        "axesOrientationModeChanged",
        "AxesOrientationMode",
        "axesOrientationMode",
        "currentOrientationChanged",
        "currentOrientation",
        "userOrientationChanged",
        "userOrientation",
        "maxBufferSizeChanged",
        "maxBufferSize",
        "efficientBufferSizeChanged",
        "efficientBufferSize",
        "bufferSizeChanged",
        "bufferSize",
        "identifierChanged",
        "start",
        "stop",
        "connectToBackend",
        "isFeatureSupported",
        "Feature",
        "feature",
        "identifier",
        "type",
        "connectedToBackend",
        "availableDataRates",
        "qrangelist",
        "dataRate",
        "reading",
        "QSensorReading*",
        "busy",
        "active",
        "outputRanges",
        "qoutputrangelist",
        "outputRange",
        "description",
        "alwaysOn",
        "Buffering",
        "AlwaysOn",
        "GeoValues",
        "FieldOfView",
        "AccelerationMode",
        "SkipDuplicates",
        "AxesOrientation",
        "PressureSensorTemperature",
        "Reserved",
        "FixedOrientation",
        "AutomaticOrientation",
        "UserOrientation"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'busyChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readingChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sensorError'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'availableSensorsChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alwaysOnChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataRateChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'skipDuplicatesChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'axesOrientationModeChanged'
        QtMocHelpers::SignalData<void(enum AxesOrientationMode)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'currentOrientationChanged'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'userOrientationChanged'
        QtMocHelpers::SignalData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Signal 'maxBufferSizeChanged'
        QtMocHelpers::SignalData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Signal 'efficientBufferSizeChanged'
        QtMocHelpers::SignalData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Signal 'bufferSizeChanged'
        QtMocHelpers::SignalData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Signal 'identifierChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'start'
        QtMocHelpers::SlotData<bool()>(26, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'connectToBackend'
        QtMocHelpers::MethodData<bool()>(28, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'isFeatureSupported'
        QtMocHelpers::MethodData<bool(enum Feature) const>(29, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 30, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'identifier'
        QtMocHelpers::PropertyData<QByteArray>(32, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'type'
        QtMocHelpers::PropertyData<QByteArray>(33, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'connectedToBackend'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'availableDataRates'
        QtMocHelpers::PropertyData<qrangelist>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'dataRate'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'reading'
        QtMocHelpers::PropertyData<QSensorReading*>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'busy'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'outputRanges'
        QtMocHelpers::PropertyData<qoutputrangelist>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'outputRange'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'error'
        QtMocHelpers::PropertyData<int>(6, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'alwaysOn'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'skipDuplicates'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'axesOrientationMode'
        QtMocHelpers::PropertyData<enum AxesOrientationMode>(14, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'currentOrientation'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags, 9),
        // property 'userOrientation'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'maxBufferSize'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags, 11),
        // property 'efficientBufferSize'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags, 12),
        // property 'bufferSize'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Feature'
        QtMocHelpers::EnumData<enum Feature>(30, 30, QMC::EnumFlags{}).add({
            {   47, Feature::Buffering },
            {   48, Feature::AlwaysOn },
            {   49, Feature::GeoValues },
            {   50, Feature::FieldOfView },
            {   51, Feature::AccelerationMode },
            {   52, Feature::SkipDuplicates },
            {   53, Feature::AxesOrientation },
            {   54, Feature::PressureSensorTemperature },
            {   55, Feature::Reserved },
        }),
        // enum 'AxesOrientationMode'
        QtMocHelpers::EnumData<enum AxesOrientationMode>(13, 13, QMC::EnumFlags{}).add({
            {   56, AxesOrientationMode::FixedOrientation },
            {   57, AxesOrientationMode::AutomaticOrientation },
            {   58, AxesOrientationMode::UserOrientation },
        }),
    };
    return QtMocHelpers::metaObjectData<QSensor, qt_meta_tag_ZN7QSensorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QSensor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7QSensorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7QSensorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7QSensorE_t>.metaTypes,
    nullptr
} };

void QSensor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QSensor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->busyChanged(); break;
        case 1: _t->activeChanged(); break;
        case 2: _t->readingChanged(); break;
        case 3: _t->sensorError((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->availableSensorsChanged(); break;
        case 5: _t->alwaysOnChanged(); break;
        case 6: _t->dataRateChanged(); break;
        case 7: _t->skipDuplicatesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->axesOrientationModeChanged((*reinterpret_cast<std::add_pointer_t<enum AxesOrientationMode>>(_a[1]))); break;
        case 9: _t->currentOrientationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->userOrientationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->maxBufferSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->efficientBufferSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->bufferSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->identifierChanged(); break;
        case 15: { bool _r = _t->start();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->stop(); break;
        case 17: { bool _r = _t->connectToBackend();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->isFeatureSupported((*reinterpret_cast<std::add_pointer_t<enum Feature>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)()>(_a, &QSensor::busyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)()>(_a, &QSensor::activeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)()>(_a, &QSensor::readingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)(int )>(_a, &QSensor::sensorError, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)()>(_a, &QSensor::availableSensorsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)()>(_a, &QSensor::alwaysOnChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)()>(_a, &QSensor::dataRateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)(bool )>(_a, &QSensor::skipDuplicatesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)(AxesOrientationMode )>(_a, &QSensor::axesOrientationModeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)(int )>(_a, &QSensor::currentOrientationChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)(int )>(_a, &QSensor::userOrientationChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)(int )>(_a, &QSensor::maxBufferSizeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)(int )>(_a, &QSensor::efficientBufferSizeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)(int )>(_a, &QSensor::bufferSizeChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSensor::*)()>(_a, &QSensor::identifierChanged, 14))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QSensorReading* >(); break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< qoutputrangelist >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< qrangelist >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QByteArray*>(_v) = _t->identifier(); break;
        case 1: *reinterpret_cast<QByteArray*>(_v) = _t->type(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isConnectedToBackend(); break;
        case 3: *reinterpret_cast<qrangelist*>(_v) = _t->availableDataRates(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->dataRate(); break;
        case 5: *reinterpret_cast<QSensorReading**>(_v) = _t->reading(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isBusy(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isActive(); break;
        case 8: *reinterpret_cast<qoutputrangelist*>(_v) = _t->outputRanges(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->outputRange(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->error(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isAlwaysOn(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->skipDuplicates(); break;
        case 14: *reinterpret_cast<enum AxesOrientationMode*>(_v) = _t->axesOrientationMode(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->currentOrientation(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->userOrientation(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->maxBufferSize(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->efficientBufferSize(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->bufferSize(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIdentifier(*reinterpret_cast<QByteArray*>(_v)); break;
        case 4: _t->setDataRate(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setOutputRange(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setAlwaysOn(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setSkipDuplicates(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setAxesOrientationMode(*reinterpret_cast<enum AxesOrientationMode*>(_v)); break;
        case 16: _t->setUserOrientation(*reinterpret_cast<int*>(_v)); break;
        case 19: _t->setBufferSize(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QSensor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QSensor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7QSensorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QSensor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void QSensor::busyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QSensor::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QSensor::readingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QSensor::sensorError(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QSensor::availableSensorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QSensor::alwaysOnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QSensor::dataRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QSensor::skipDuplicatesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void QSensor::axesOrientationModeChanged(AxesOrientationMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void QSensor::currentOrientationChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void QSensor::userOrientationChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void QSensor::maxBufferSizeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void QSensor::efficientBufferSizeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void QSensor::bufferSizeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void QSensor::identifierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
namespace {
struct qt_meta_tag_ZN14QSensorReadingE_t {};
} // unnamed namespace

template <> constexpr inline auto QSensorReading::qt_create_metaobjectdata<qt_meta_tag_ZN14QSensorReadingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QSensorReading",
        "timestamp"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'timestamp'
        QtMocHelpers::PropertyData<quint64>(1, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QSensorReading, qt_meta_tag_ZN14QSensorReadingE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QSensorReading::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QSensorReadingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QSensorReadingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14QSensorReadingE_t>.metaTypes,
    nullptr
} };

void QSensorReading::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QSensorReading *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<quint64*>(_v) = _t->timestamp(); break;
        default: break;
        }
    }
}

const QMetaObject *QSensorReading::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QSensorReading::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QSensorReadingE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QSensorReading::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
