/****************************************************************************
** Meta object code from reading C++ file 'qmlaccelerometer_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtsensors/src/sensorsquick/qmlaccelerometer_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlaccelerometer_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16QmlAccelerometerE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlAccelerometer::qt_create_metaobjectdata<qt_meta_tag_ZN16QmlAccelerometerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlAccelerometer",
        "QML.Element",
        "Accelerometer",
        "QML.AddedInVersion",
        "1280",
        "accelerationModeChanged",
        "",
        "AccelerationMode",
        "accelerationMode",
        "Combined",
        "Gravity",
        "User"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accelerationModeChanged'
        QtMocHelpers::RevisionedSignalData<void(enum AccelerationMode)>(5, 6, QMC::AccessPublic, 0xff01, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'accelerationMode'
        QtMocHelpers::PropertyData<enum AccelerationMode>(8, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0, 0xff01),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AccelerationMode'
        QtMocHelpers::EnumData<enum AccelerationMode>(7, 7, QMC::EnumFlags{}).add({
            {    9, AccelerationMode::Combined },
            {   10, AccelerationMode::Gravity },
            {   11, AccelerationMode::User },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QmlAccelerometer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QmlAccelerometer::staticMetaObject = { {
    QMetaObject::SuperData::link<QmlSensor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QmlAccelerometerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QmlAccelerometerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16QmlAccelerometerE_t>.metaTypes,
    nullptr
} };

void QmlAccelerometer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlAccelerometer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accelerationModeChanged((*reinterpret_cast<std::add_pointer_t<enum AccelerationMode>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlAccelerometer::*)(AccelerationMode )>(_a, &QmlAccelerometer::accelerationModeChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum AccelerationMode*>(_v) = _t->accelerationMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAccelerationMode(*reinterpret_cast<enum AccelerationMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QmlAccelerometer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlAccelerometer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QmlAccelerometerE_t>.strings))
        return static_cast<void*>(this);
    return QmlSensor::qt_metacast(_clname);
}

int QmlAccelerometer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QmlSensor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void QmlAccelerometer::accelerationModeChanged(AccelerationMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN23QmlAccelerometerReadingE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlAccelerometerReading::qt_create_metaobjectdata<qt_meta_tag_ZN23QmlAccelerometerReadingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlAccelerometerReading",
        "QML.Element",
        "AccelerometerReading",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Cannot create AccelerometerReading",
        "QML.AddedInVersion",
        "1280",
        "xChanged",
        "",
        "yChanged",
        "zChanged",
        "x",
        "y",
        "z"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'xChanged'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'yChanged'
        QtMocHelpers::SignalData<void()>(11, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zChanged'
        QtMocHelpers::SignalData<void()>(12, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'x'
        QtMocHelpers::PropertyData<qreal>(13, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Bindable, 0),
        // property 'y'
        QtMocHelpers::PropertyData<qreal>(14, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'z'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Bindable, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<QmlAccelerometerReading, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QmlAccelerometerReading::staticMetaObject = { {
    QMetaObject::SuperData::link<QmlSensorReading::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QmlAccelerometerReadingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QmlAccelerometerReadingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23QmlAccelerometerReadingE_t>.metaTypes,
    nullptr
} };

void QmlAccelerometerReading::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlAccelerometerReading *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->xChanged(); break;
        case 1: _t->yChanged(); break;
        case 2: _t->zChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlAccelerometerReading::*)()>(_a, &QmlAccelerometerReading::xChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlAccelerometerReading::*)()>(_a, &QmlAccelerometerReading::yChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlAccelerometerReading::*)()>(_a, &QmlAccelerometerReading::zChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->y(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->z(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableX(); break;
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableY(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableZ(); break;
        default: break;
        }
    }
}

const QMetaObject *QmlAccelerometerReading::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlAccelerometerReading::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QmlAccelerometerReadingE_t>.strings))
        return static_cast<void*>(this);
    return QmlSensorReading::qt_metacast(_clname);
}

int QmlAccelerometerReading::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QmlSensorReading::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void QmlAccelerometerReading::xChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QmlAccelerometerReading::yChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QmlAccelerometerReading::zChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
