// This file is autogenerated. Changes will be overwritten.
#include "EJRQKI7XPS/moc_compass_interface.cpp"
#include "EJRQKI7XPS/moc_properties_interface.cpp"
#include "EJRQKI7XPS/moc_sensorproxy_interface.cpp"
#include "EWIEGA46WW/moc_iiosensorproxycompass.cpp"
#include "EWIEGA46WW/moc_iiosensorproxylightsensor.cpp"
#include "EWIEGA46WW/moc_iiosensorproxyorientationsensor.cpp"
#include "EWIEGA46WW/moc_iiosensorproxyproximitysensor.cpp"
#include "EWIEGA46WW/moc_iiosensorproxysensorbase.cpp"
