/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<private/qmlaccelerometer_p.h>)
#  include <private/qmlaccelerometer_p.h>
#endif
#if __has_include(<private/qmlambientlightsensor_p.h>)
#  include <private/qmlambientlightsensor_p.h>
#endif
#if __has_include(<private/qmlambienttemperaturesensor_p.h>)
#  include <private/qmlambienttemperaturesensor_p.h>
#endif
#if __has_include(<private/qmlcompass_p.h>)
#  include <private/qmlcompass_p.h>
#endif
#if __has_include(<private/qmlgyroscope_p.h>)
#  include <private/qmlgyroscope_p.h>
#endif
#if __has_include(<private/qmlhumiditysensor_p.h>)
#  include <private/qmlhumiditysensor_p.h>
#endif
#if __has_include(<private/qmlirproximitysensor_p.h>)
#  include <private/qmlirproximitysensor_p.h>
#endif
#if __has_include(<private/qmllidsensor_p.h>)
#  include <private/qmllidsensor_p.h>
#endif
#if __has_include(<private/qmllightsensor_p.h>)
#  include <private/qmllightsensor_p.h>
#endif
#if __has_include(<private/qmlmagnetometer_p.h>)
#  include <private/qmlmagnetometer_p.h>
#endif
#if __has_include(<private/qmlorientationsensor_p.h>)
#  include <private/qmlorientationsensor_p.h>
#endif
#if __has_include(<private/qmlpressuresensor_p.h>)
#  include <private/qmlpressuresensor_p.h>
#endif
#if __has_include(<private/qmlproximitysensor_p.h>)
#  include <private/qmlproximitysensor_p.h>
#endif
#if __has_include(<private/qmlrotationsensor_p.h>)
#  include <private/qmlrotationsensor_p.h>
#endif
#if __has_include(<private/qmlsensor_p.h>)
#  include <private/qmlsensor_p.h>
#endif
#if __has_include(<private/qmlsensorglobal_p.h>)
#  include <private/qmlsensorglobal_p.h>
#endif
#if __has_include(<private/qmlsensorrange_p.h>)
#  include <private/qmlsensorrange_p.h>
#endif
#if __has_include(<private/qmltapsensor_p.h>)
#  include <private/qmltapsensor_p.h>
#endif
#if __has_include(<private/qmltiltsensor_p.h>)
#  include <private/qmltiltsensor_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtSensors()
{
    qmlRegisterModule("QtSensors", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<QmlAccelerometer>("QtSensors", 6);
    qmlRegisterEnum<QmlAccelerometer::AccelerationMode>("QmlAccelerometer::AccelerationMode");
    qmlRegisterTypesAndRevisions<QmlAccelerometerReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlAmbientLightSensor>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlAmbientLightSensorReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlAmbientTemperatureReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlAmbientTemperatureSensor>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlCompass>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlCompassReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlGyroscope>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlGyroscopeReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlHumidityReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlHumiditySensor>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlIRProximitySensor>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlIRProximitySensorReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlLidReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlLidSensor>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlLightSensor>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlLightSensorReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlMagnetometer>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlMagnetometerReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlOrientationSensor>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlOrientationSensorReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlPressureReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlPressureSensor>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlProximitySensor>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlProximitySensorReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlRotationSensor>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlRotationSensorReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlSensor>("QtSensors", 6);
    qmlRegisterEnum<QmlSensor::Feature>("QmlSensor::Feature");
    qmlRegisterEnum<QmlSensor::AxesOrientationMode>("QmlSensor::AxesOrientationMode");
    qmlRegisterTypesAndRevisions<QmlSensorGlobal>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlSensorOutputRange>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlSensorRange>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlSensorReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlTapSensor>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlTapSensorReading>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlTiltSensor>("QtSensors", 6);
    qmlRegisterTypesAndRevisions<QmlTiltSensorReading>("QtSensors", 6);
    QT_WARNING_POP
    qmlRegisterModule("QtSensors", 6, 11);
}

static const QQmlModuleRegistration qtSensorsRegistration("QtSensors", qml_register_types_QtSensors);
