/****************************************************************************
** Meta object code from reading C++ file 'qmlsensor_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtsensors/src/sensorsquick/qmlsensor_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlsensor_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9QmlSensorE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlSensor::qt_create_metaobjectdata<qt_meta_tag_ZN9QmlSensorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlSensor",
        "QML.Element",
        "Sensor",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Cannot create Sensor",
        "QML.AddedInVersion",
        "1280",
        "identifierChanged",
        "",
        "connectedToBackendChanged",
        "availableDataRatesChanged",
        "dataRateChanged",
        "readingChanged",
        "activeChanged",
        "outputRangesChanged",
        "outputRangeChanged",
        "descriptionChanged",
        "errorChanged",
        "alwaysOnChanged",
        "busyChanged",
        "skipDuplicatesChanged",
        "skipDuplicates",
        "axesOrientationModeChanged",
        "AxesOrientationMode",
        "axesOrientationMode",
        "currentOrientationChanged",
        "currentOrientation",
        "userOrientationChanged",
        "userOrientation",
        "maxBufferSizeChanged",
        "maxBufferSize",
        "efficientBufferSizeChanged",
        "efficientBufferSize",
        "bufferSizeChanged",
        "bufferSize",
        "start",
        "stop",
        "updateReading",
        "isFeatureSupported",
        "Feature",
        "feature",
        "identifier",
        "type",
        "connectedToBackend",
        "availableDataRates",
        "QQmlListProperty<QmlSensorRange>",
        "dataRate",
        "reading",
        "QmlSensorReading*",
        "busy",
        "active",
        "outputRanges",
        "QQmlListProperty<QmlSensorOutputRange>",
        "outputRange",
        "description",
        "error",
        "alwaysOn",
        "Buffering",
        "AlwaysOn",
        "GeoValues",
        "FieldOfView",
        "AccelerationMode",
        "SkipDuplicates",
        "AxesOrientation",
        "PressureSensorTemperature",
        "FixedOrientation",
        "AutomaticOrientation",
        "UserOrientation"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'identifierChanged'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connectedToBackendChanged'
        QtMocHelpers::SignalData<void()>(11, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableDataRatesChanged'
        QtMocHelpers::SignalData<void()>(12, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataRateChanged'
        QtMocHelpers::SignalData<void()>(13, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readingChanged'
        QtMocHelpers::SignalData<void()>(14, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(15, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputRangesChanged'
        QtMocHelpers::SignalData<void()>(16, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputRangeChanged'
        QtMocHelpers::SignalData<void()>(17, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionChanged'
        QtMocHelpers::SignalData<void()>(18, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorChanged'
        QtMocHelpers::SignalData<void()>(19, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alwaysOnChanged'
        QtMocHelpers::SignalData<void()>(20, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'busyChanged'
        QtMocHelpers::SignalData<void()>(21, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'skipDuplicatesChanged'
        QtMocHelpers::RevisionedSignalData<void(bool)>(22, 10, QMC::AccessPublic, 0xff01, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'axesOrientationModeChanged'
        QtMocHelpers::RevisionedSignalData<void(enum AxesOrientationMode)>(24, 10, QMC::AccessPublic, 0xff01, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Signal 'currentOrientationChanged'
        QtMocHelpers::RevisionedSignalData<void(int)>(27, 10, QMC::AccessPublic, 0xff01, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Signal 'userOrientationChanged'
        QtMocHelpers::RevisionedSignalData<void(int)>(29, 10, QMC::AccessPublic, 0xff01, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Signal 'maxBufferSizeChanged'
        QtMocHelpers::RevisionedSignalData<void(int)>(31, 10, QMC::AccessPublic, 0xff01, QMetaType::Void, {{
            { QMetaType::Int, 32 },
        }}),
        // Signal 'efficientBufferSizeChanged'
        QtMocHelpers::RevisionedSignalData<void(int)>(33, 10, QMC::AccessPublic, 0xff01, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Signal 'bufferSizeChanged'
        QtMocHelpers::RevisionedSignalData<void(int)>(35, 10, QMC::AccessPublic, 0xff01, QMetaType::Void, {{
            { QMetaType::Int, 36 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<bool()>(37, 10, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(38, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateReading'
        QtMocHelpers::SlotData<void()>(39, 10, QMC::AccessPrivate, QMetaType::Void),
        // Method 'isFeatureSupported'
        QtMocHelpers::RevisionedMethodData<bool(enum Feature) const>(40, 10, QMC::AccessPublic, 0x607, QMetaType::Bool, {{
            { 0x80000000 | 41, 42 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'identifier'
        QtMocHelpers::PropertyData<QByteArray>(43, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'type'
        QtMocHelpers::PropertyData<QByteArray>(44, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'connectedToBackend'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'availableDataRates'
        QtMocHelpers::PropertyData<QQmlListProperty<QmlSensorRange>>(46, 0x80000000 | 47, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'dataRate'
        QtMocHelpers::PropertyData<int>(48, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'reading'
        QtMocHelpers::PropertyData<QmlSensorReading*>(49, 0x80000000 | 50, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 4),
        // property 'busy'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'outputRanges'
        QtMocHelpers::PropertyData<QQmlListProperty<QmlSensorOutputRange>>(53, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'outputRange'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(56, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'error'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags, 9),
        // property 'alwaysOn'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'skipDuplicates'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12, 0xff01),
        // property 'axesOrientationMode'
        QtMocHelpers::PropertyData<enum AxesOrientationMode>(26, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13, 0xff01),
        // property 'currentOrientation'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags, 14, 0xff01),
        // property 'userOrientation'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15, 0xff01),
        // property 'maxBufferSize'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags, 16, 0xff01),
        // property 'efficientBufferSize'
        QtMocHelpers::PropertyData<int>(34, QMetaType::Int, QMC::DefaultPropertyFlags, 17, 0xff01),
        // property 'bufferSize'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18, 0xff01),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Feature'
        QtMocHelpers::EnumData<enum Feature>(41, 41, QMC::EnumFlags{}).add({
            {   59, Feature::Buffering },
            {   60, Feature::AlwaysOn },
            {   61, Feature::GeoValues },
            {   62, Feature::FieldOfView },
            {   63, Feature::AccelerationMode },
            {   64, Feature::SkipDuplicates },
            {   65, Feature::AxesOrientation },
            {   66, Feature::PressureSensorTemperature },
        }),
        // enum 'AxesOrientationMode'
        QtMocHelpers::EnumData<enum AxesOrientationMode>(25, 25, QMC::EnumFlags{}).add({
            {   67, AxesOrientationMode::FixedOrientation },
            {   68, AxesOrientationMode::AutomaticOrientation },
            {   69, AxesOrientationMode::UserOrientation },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<QmlSensor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QmlSensor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QmlSensorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QmlSensorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9QmlSensorE_t>.metaTypes,
    nullptr
} };

void QmlSensor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlSensor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->identifierChanged(); break;
        case 1: _t->connectedToBackendChanged(); break;
        case 2: _t->availableDataRatesChanged(); break;
        case 3: _t->dataRateChanged(); break;
        case 4: _t->readingChanged(); break;
        case 5: _t->activeChanged(); break;
        case 6: _t->outputRangesChanged(); break;
        case 7: _t->outputRangeChanged(); break;
        case 8: _t->descriptionChanged(); break;
        case 9: _t->errorChanged(); break;
        case 10: _t->alwaysOnChanged(); break;
        case 11: _t->busyChanged(); break;
        case 12: _t->skipDuplicatesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->axesOrientationModeChanged((*reinterpret_cast<std::add_pointer_t<enum AxesOrientationMode>>(_a[1]))); break;
        case 14: _t->currentOrientationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->userOrientationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->maxBufferSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->efficientBufferSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->bufferSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: { bool _r = _t->start();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->stop(); break;
        case 21: _t->updateReading(); break;
        case 22: { bool _r = _t->isFeatureSupported((*reinterpret_cast<std::add_pointer_t<enum Feature>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)()>(_a, &QmlSensor::identifierChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)()>(_a, &QmlSensor::connectedToBackendChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)()>(_a, &QmlSensor::availableDataRatesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)()>(_a, &QmlSensor::dataRateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)()>(_a, &QmlSensor::readingChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)()>(_a, &QmlSensor::activeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)()>(_a, &QmlSensor::outputRangesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)()>(_a, &QmlSensor::outputRangeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)()>(_a, &QmlSensor::descriptionChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)()>(_a, &QmlSensor::errorChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)()>(_a, &QmlSensor::alwaysOnChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)()>(_a, &QmlSensor::busyChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)(bool )>(_a, &QmlSensor::skipDuplicatesChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)(AxesOrientationMode )>(_a, &QmlSensor::axesOrientationModeChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)(int )>(_a, &QmlSensor::currentOrientationChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)(int )>(_a, &QmlSensor::userOrientationChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)(int )>(_a, &QmlSensor::maxBufferSizeChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)(int )>(_a, &QmlSensor::efficientBufferSizeChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlSensor::*)(int )>(_a, &QmlSensor::bufferSizeChanged, 18))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QmlSensorReading* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QByteArray*>(_v) = _t->identifier(); break;
        case 1: *reinterpret_cast<QByteArray*>(_v) = _t->type(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isConnectedToBackend(); break;
        case 3: *reinterpret_cast<QQmlListProperty<QmlSensorRange>*>(_v) = _t->availableDataRates(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->dataRate(); break;
        case 5: *reinterpret_cast<QmlSensorReading**>(_v) = _t->reading(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isBusy(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isActive(); break;
        case 8: *reinterpret_cast<QQmlListProperty<QmlSensorOutputRange>*>(_v) = _t->outputRanges(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->outputRange(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->error(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isAlwaysOn(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->skipDuplicates(); break;
        case 14: *reinterpret_cast<enum AxesOrientationMode*>(_v) = _t->axesOrientationMode(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->currentOrientation(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->userOrientation(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->maxBufferSize(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->efficientBufferSize(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->bufferSize(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIdentifier(*reinterpret_cast<QByteArray*>(_v)); break;
        case 4: _t->setDataRate(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setOutputRange(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setAlwaysOn(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setSkipDuplicates(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setAxesOrientationMode(*reinterpret_cast<enum AxesOrientationMode*>(_v)); break;
        case 16: _t->setUserOrientation(*reinterpret_cast<int*>(_v)); break;
        case 19: _t->setBufferSize(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 5: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableReading(); break;
        default: break;
        }
    }
}

const QMetaObject *QmlSensor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlSensor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QmlSensorE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlSensor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void QmlSensor::identifierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QmlSensor::connectedToBackendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QmlSensor::availableDataRatesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QmlSensor::dataRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QmlSensor::readingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QmlSensor::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QmlSensor::outputRangesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QmlSensor::outputRangeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QmlSensor::descriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QmlSensor::errorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QmlSensor::alwaysOnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QmlSensor::busyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QmlSensor::skipDuplicatesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void QmlSensor::axesOrientationModeChanged(AxesOrientationMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void QmlSensor::currentOrientationChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void QmlSensor::userOrientationChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void QmlSensor::maxBufferSizeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void QmlSensor::efficientBufferSizeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void QmlSensor::bufferSizeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN16QmlSensorReadingE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlSensorReading::qt_create_metaobjectdata<qt_meta_tag_ZN16QmlSensorReadingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlSensorReading",
        "QML.Element",
        "SensorReading",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Cannot create SensorReading",
        "QML.AddedInVersion",
        "1280",
        "timestampChanged",
        "",
        "timestamp"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'timestampChanged'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'timestamp'
        QtMocHelpers::PropertyData<quint64>(11, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Bindable, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<QmlSensorReading, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QmlSensorReading::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QmlSensorReadingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QmlSensorReadingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16QmlSensorReadingE_t>.metaTypes,
    nullptr
} };

void QmlSensorReading::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlSensorReading *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->timestampChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlSensorReading::*)()>(_a, &QmlSensorReading::timestampChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<quint64*>(_v) = _t->timestamp(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableTimestamp(); break;
        default: break;
        }
    }
}

const QMetaObject *QmlSensorReading::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlSensorReading::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QmlSensorReadingE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlSensorReading::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void QmlSensorReading::timestampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
